"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.encryptBundle = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const logger_1 = require("./logger");
async function encryptBundle(inputFile, outputPath, platform) {
    const rnEncrypt = tryRequire('rn_encrypt');
    if (rnEncrypt == null) {
        (0, logger_1.dbg)('无法找到 rn_encrypt 模块，跳过加密');
        return null;
    }
    const safetyOutputPath = outputPath;
    const tempFilePath = `${safetyOutputPath}${path_1.default.sep}temp_${platform}.dat`;
    const sourceMapPath = `${inputFile}.map`;
    const md5 = await rnEncrypt.compressAndEncrypt(inputFile, tempFilePath);
    const outputFilePath = path_1.default.join(safetyOutputPath, `${md5}_${platform.toLowerCase()}.dat`);
    if (fs_extra_1.default.existsSync(tempFilePath)) {
        fs_extra_1.default.moveSync(tempFilePath, outputFilePath);
        if (fs_extra_1.default.existsSync(sourceMapPath)) {
            const fileInfo = path_1.default.parse(sourceMapPath);
            fs_extra_1.default.copySync(sourceMapPath, path_1.default.join(safetyOutputPath, fileInfo.base));
        }
    }
    else {
        throw new Error('无法找到加密的bundle:' + tempFilePath);
    }
    return {
        outputFilePath,
        md5
    };
}
exports.encryptBundle = encryptBundle;
function tryRequire(module) {
    try {
        return require(module);
    }
    catch (error) {
        return null;
    }
}
