import { ExtCLI } from "@hyext/cli";
export type BundleType = "RN_BUNDLE" | "MINI_GAME_RN" | string;
type GenerateUrlOption = {
    extType: string;
    extUuid: string;
    registerComponent: string;
    SDKVersion: string;
    md5: string;
    rnbaseurl?: string;
    rnbasemd5?: string;
    RNVersion?: string;
};
export declare function generateProdUrl({ extType, extUuid, registerComponent, SDKVersion, md5, rnbaseurl, rnbasemd5, RNVersion, }: GenerateUrlOption): string;
interface BuildInfo {
    extType: ExtCLI.RNExtType;
    bundleRelativePath: string;
    registerComponents: {
        name: string;
        queryString?: string;
    }[];
    platform: ExtCLI.RNPlatform;
    SDKVersion: string;
    publicPath: string;
    bundleType?: BundleType;
}
interface ProdBuildInfo extends BuildInfo {
    bundleMd5: string;
    baseUrl?: string;
    baseMd5?: string;
}
interface UniformBuildInfo extends BuildInfo {
    registerComponents: {
        name: string;
        queryString: string;
    }[];
}
export interface BaseOptions {
    builderName: string;
    extendPlatformConfig?: ExtendPlatformConfig;
    extendExtTypeConfig?: ExtendExtTypeConfig;
}
interface ProdOptions extends BaseOptions {
    extInfo: {
        packageName: string;
        extUuid: string;
    };
    buildResultConfig: ProdBuildInfo[];
    onUrlCreateBefore?: onUrlCreateBefore;
}
interface DevOptions extends BaseOptions {
    buildResultConfig: BuildInfo[];
}
interface UniformOptions extends BaseOptions {
    buildResultConfig: UniformBuildInfo[];
}
type onUrlCreateBefore = (opts: GenerateUrlOption, platform: string) => GenerateUrlOption;
/** 在生成 buildResult 的 platform 字段(ios/android) 前调用 */
type ExtendPlatformConfig = <T extends ExtCLI.RNBuildResultPlatformConfig>(rawConfig: T, platform: ExtCLI.RNPlatform, extType: string) => Promise<T>;
/** 在每个extType 的每个platform 都会调用一次 */
type ExtendExtTypeConfig = <T extends ExtCLI.RNBuildResult[keyof ExtCLI.RNBuildResult]>(rawConfig: T, extType: ExtCLI.RNExtType, platform: ExtCLI.RNPlatform) => Promise<T>;
export declare function generateProdBuildResult({ builderName, extInfo, buildResultConfig, onUrlCreateBefore, extendPlatformConfig, extendExtTypeConfig, }: ProdOptions): Promise<ExtCLI.RNBuildResult>;
export declare function generateProdBuildResultWithEncrypt({ builderName, extInfo, buildResultConfig, onUrlCreateBefore, extendExtTypeConfig, outputBasePath }: ProdOptions & {
    /**
      * jsbundle 的基础路径
      * 使用 outputBasePath + platformConfig.path 即可得到jsbundle的绝对路径
      * 使用 outputBasePath + 'horizon' + extType + md5_ios.dat 即可得到混淆后的jsbundle的绝对路径
      */
    outputBasePath: string;
}): Promise<ExtCLI.RNBuildResult>;
export declare function generateDevBuildResult({ builderName, buildResultConfig, extendExtTypeConfig, extendPlatformConfig, }: DevOptions): Promise<ExtCLI.RNBuildResult>;
export declare function generateBuildResult({ builderName, buildResultConfig, extendPlatformConfig, extendExtTypeConfig, }: UniformOptions): Promise<ExtCLI.RNBuildResult>;
export {};
