"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.batchCompile = void 0;
// @ts-ignore
const DependencyGraph_1 = __importDefault(require("metro/src/node-haste/DependencyGraph"));
// @ts-ignore
const Transformer_1 = __importDefault(require("metro/src/DeltaBundler/Transformer"));
// @ts-ignore
const DeltaCalculator_1 = __importDefault(require("metro/src/DeltaBundler/DeltaCalculator"));
// @ts-ignore
const saveAssets_1 = __importDefault(require("@react-native-community/cli-plugin-metro/build/commands/bundle/saveAssets"));
const saveOutput_1 = __importDefault(require("./saveOutput"));
const calcTransformerOptions_1 = require("./calcTransformerOptions");
const getType_1 = require("./getType");
const getAssets_1 = require("./getAssets");
const getPrepended_1 = require("./getPrepended");
const getExtMetroConfig_1 = require("../matrix-config/getExtMetroConfig");
async function batchCompile({ config, bundleConfigs, }) {
    var _a;
    const serializerOptions = {
        excludeSource: false,
        inlineSourceMap: false,
        modulesOnly: false,
        runModule: true,
        sourceMapUrl: undefined,
        sourceUrl: undefined,
    };
    const dependencyGraph = await DependencyGraph_1.default.load(config, { watch: false });
    const transformer = new Transformer_1.default(config, dependencyGraph.getSha1.bind(dependencyGraph));
    const absoluteEntryFiles = bundleConfigs.map(xs => xs.entryAbsPath);
    const getPlatformGraph = async (platform) => {
        var _a, _b;
        const transformOptions = {
            customTransformOptions: Object.assign(Object.create(null), {
                extraTransformerCacheKey: JSON.stringify({
                    babelPlugins: config.babelPlugins,
                    hyextTransformerConfig: config.hyextTransformerConfig,
                })
            }),
            dev: config.mode === 'development',
            hot: false,
            minify: config.mode === 'production',
            platform,
            runtimeBytecodeVersion: undefined,
            type: 'module',
            unstable_transformProfile: 'default',
        };
        const calculatedOptions = await (0, calcTransformerOptions_1.calcTransformerOptions)(config, transformOptions);
        const deltaCalculator = new DeltaCalculator_1.default(absoluteEntryFiles, dependencyGraph, {
            resolve: (from, to) => dependencyGraph.resolveDependency(from, to, platform),
            transform: (filepath) => {
                if (!config.serializer.processModuleFilter({ path: filepath })) {
                    return Promise.resolve(getExtMetroConfig_1.skipModulePlaceHolder);
                }
                return transformer.transformFile(filepath, {
                    ...calculatedOptions,
                    type: (0, getType_1.getType)(config, calculatedOptions, filepath),
                    inlineRequires: false,
                });
            },
            transformOptions,
            onProgress: null,
            experimentalImportBundleSupport: false,
            shallow: false,
        });
        await deltaCalculator.getDelta({ reset: true, shallow: false });
        const graph = deltaCalculator.getGraph();
        (_b = (_a = config.serializer) === null || _a === void 0 ? void 0 : _a.experimentalSerializerHook) === null || _b === void 0 ? void 0 : _b.call(_a, graph, {
            added: graph.dependencies,
            modified: new Map(),
            deleted: new Set(),
            reset: true,
        });
        const _getAssets = () => {
            if (platform === 'ios') {
                return (0, getAssets_1.getAssets)({
                    entryFiles: absoluteEntryFiles,
                    config,
                    transformOptions,
                    dependencyGraph,
                    transformer,
                });
            }
            return [];
        };
        const [prepend, assets] = await Promise.all([
            (0, getPrepended_1.getPrepended)({
                config,
                transformOptions,
                dependencyGraph,
                platform,
                transformer,
                extraVars: {
                    __HYEXT_RN_VER__: `${process.env.HYEXT_RN_VER || '0.67.2'}`,
                    HYEXT_BUILD_ENV: `${process.env.HYEXT_BUILD_ENV || 'dev'}`,
                    HYEXT_BUILD_TYPE: 'rn',
                    HYEXT_IMAGE_BASE_URL: config.imageBaseURL.endsWith('/')
                        ? config.imageBaseURL.slice(0, config.imageBaseURL.length - 1)
                        : config.imageBaseURL,
                },
            }),
            _getAssets(),
        ]);
        return { graph, prepend, deltaCalculator, platform, assets };
    };
    // 这里用 Promise.all 对速度并没有任何提升, 还不如一个个来比较稳妥
    const graphList = [];
    graphList.push(await getPlatformGraph('ios'));
    graphList.push(await getPlatformGraph('android'));
    const promiseFactories = [];
    bundleConfigs.forEach(xs => {
        graphList.forEach(grph => {
            let bundleName = `index.${grph.platform}.${config.mode === 'development' ? 'bundle' : 'jsbundle'}`;
            const expUuids = JSON.parse(process.env.MATRIX_EXP_EXT_UUIDS || '[]');
            const extUuid = process.env.MATRIX_EXT_UUID || 'index';
            if (expUuids.includes(extUuid)) {
                const extVer = process.env.MATRIX_EXT_VER || '0.0.0';
                bundleName = `${extUuid}.${extVer}.${xs.id}.${grph.platform}.jsbundle`;
            }
            promiseFactories.push(() => (0, saveOutput_1.default)({
                entryAbsPath: xs.entryAbsPath,
                outputDir: xs.outputDir,
                bundleName,
                id: xs.id,
                dependencyGraph,
                graph: grph.graph,
                config,
                serializerOptions,
                prepend: grph.prepend,
                platform: grph.platform,
            }));
        });
    });
    const outputList = await promiseFactories.reduce((queue, cur) => {
        return queue.then(acc => cur().then(result => ([...acc, result])));
    }, Promise.resolve([]));
    const assets = (_a = graphList.find(xs => xs.platform === 'ios')) === null || _a === void 0 ? void 0 : _a.assets;
    await (0, saveAssets_1.default)(assets, 'ios', config.assetsDir);
    graphList.forEach(({ deltaCalculator }) => deltaCalculator.end());
    transformer.end();
    dependencyGraph.end();
    return outputList;
}
exports.batchCompile = batchCompile;
