"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDependencies = void 0;
// @ts-ignore
const DeltaCalculator_1 = __importDefault(require("metro/src/DeltaBundler/DeltaCalculator"));
const calcTransformerOptions_1 = require("./calcTransformerOptions");
const getType_1 = require("./getType");
const getExtMetroConfig_1 = require("../matrix-config/getExtMetroConfig");
async function getDependencies(options) {
    const { dependencyGraph, config, entryFiles, transformOptions, transformer, otherOptions = {
        onProgress: null,
        shallow: false,
    } } = options;
    const calculatedOptions = await (0, calcTransformerOptions_1.calcTransformerOptions)(config, transformOptions);
    const deltaCalculator = new DeltaCalculator_1.default(entryFiles, dependencyGraph, {
        resolve: (from, to) => dependencyGraph.resolveDependency(from, to, transformOptions.platform),
        transform: (filepath) => {
            if (!config.serializer.processModuleFilter({ path: filepath })) {
                return Promise.resolve(getExtMetroConfig_1.skipModulePlaceHolder);
            }
            return transformer.transformFile(filepath, {
                ...calculatedOptions,
                type: (0, getType_1.getType)(config, calculatedOptions, filepath),
                inlineRequires: false,
            });
        },
        transformOptions,
        onProgress: otherOptions.onProgress,
        experimentalImportBundleSupport: config.transformer.experimentalImportBundleSupport,
        shallow: otherOptions.shallow,
    });
    await deltaCalculator.getDelta({ reset: true, shallow: otherOptions.shallow });
    const graph = deltaCalculator.getGraph();
    deltaCalculator.end();
    return graph.dependencies;
}
exports.getDependencies = getDependencies;
