"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../lib/logger");
const path_1 = __importDefault(require("path"));
const axios_1 = __importDefault(require("axios"));
const batchCompile_1 = require("./batchCompile");
const getExtMetroConfig_1 = require("../matrix-config/getExtMetroConfig");
async function compile({ mode, projectRoot, bundleConfigs, projectConfig, extMetroConfig = {}, }) {
    (0, logger_1.dbg)('compile start');
    const allStart = Date.now();
    const config = (0, getExtMetroConfig_1.getExtMetroConfig)({
        projectRoot,
        mode,
        projectConfig,
        extMetroConfig,
        isOffline: true,
    });
    (0, logger_1.dbg)('config: %O', { ...config, reporter: undefined, filterModules: undefined, filterModulesVersion: undefined });
    const result = await (0, batchCompile_1.batchCompile)({
        config,
        bundleConfigs,
    });
    const cost = Date.now() - allStart;
    (0, logger_1.dbg)('totalCompileTime: %d', cost);
    if (process.env.MATRIX_BUILD_ID) {
        const axiosConfig = {
            method: 'PUT',
            url: 'http://localhost:3002/telemetry/statExtra',
            timeout: 3000,
            data: {
                buildId: process.env.MATRIX_BUILD_ID,
                extra: [[bundleConfigs.map(xs => path_1.default.basename(xs.outputDir)).join(','), cost]]
            }
        };
        (0, logger_1.dbg)('axios Config: %s', JSON.stringify(axiosConfig));
        (0, axios_1.default)(axiosConfig).catch(err => console.error(`ignore telemetry error: ${err.message}`));
    }
    return result;
}
exports.default = compile;
